"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ensureGitStatusIsCleanAsync = ensureGitStatusIsCleanAsync;
exports.makeProjectTarballAsync = makeProjectTarballAsync;
exports.reviewAndCommitChangesAsync = reviewAndCommitChangesAsync;
exports.showDiffAsync = showDiffAsync;
exports.addFileAsync = addFileAsync;
exports.DirtyGitTreeError = void 0;

function _spawnAsync() {
  const data = _interopRequireDefault(require("@expo/spawn-async"));

  _spawnAsync = function () {
    return data;
  };

  return data;
}

function _fsExtra() {
  const data = _interopRequireDefault(require("fs-extra"));

  _fsExtra = function () {
    return data;
  };

  return data;
}

function _ora() {
  const data = _interopRequireDefault(require("ora"));

  _ora = function () {
    return data;
  };

  return data;
}

function _CommandError() {
  const data = _interopRequireDefault(require("../../../../CommandError"));

  _CommandError = function () {
    return data;
  };

  return data;
}

function _log() {
  const data = _interopRequireDefault(require("../../../../log"));

  _log = function () {
    return data;
  };

  return data;
}

function _prompts() {
  const data = _interopRequireDefault(require("../../../../prompts"));

  _prompts = function () {
    return data;
  };

  return data;
}

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function ensureGitStatusIsCleanAsync() {
  const changes = (await (0, _spawnAsync().default)('git', ['status', '-s', '-uno'])).stdout;

  if (changes.length > 0) {
    throw new DirtyGitTreeError('Please commit all changes before building your project. Aborting...');
  }
}

class DirtyGitTreeError extends Error {}

exports.DirtyGitTreeError = DirtyGitTreeError;

async function makeProjectTarballAsync(tarPath) {
  const spinner = (0, _ora().default)('Making project tarball').start();
  await (0, _spawnAsync().default)('git', ['archive', '--format=tar.gz', '--prefix', 'project/', '-o', tarPath, 'HEAD']);
  spinner.succeed('Project tarball created.');
  const {
    size
  } = await _fsExtra().default.stat(tarPath);
  return size;
}

async function showDiffAsync() {
  await (0, _spawnAsync().default)('git', ['--no-pager', 'diff'], {
    stdio: ['ignore', 'inherit', 'inherit']
  });
}

async function addFileAsync(file, options) {
  if (options === null || options === void 0 ? void 0 : options.intentToAdd) {
    await (0, _spawnAsync().default)('git', ['add', '--intent-to-add', file]);
  } else {
    await (0, _spawnAsync().default)('git', ['add', file]);
  }
}

async function reviewAndCommitChangesAsync(commitMessage, {
  nonInteractive
}) {
  if (nonInteractive) {
    throw new (_CommandError().default)('Cannot commit changes when --non-interactive is specified. Run the command in interactive mode to review and commit changes.');
  }

  (0, _log().default)('Please review the following changes and pass the message to make the commit.');

  _log().default.newLine();

  await showDiffAsync();

  _log().default.newLine();

  const {
    confirm
  } = await (0, _prompts().default)({
    type: 'confirm',
    name: 'confirm',
    message: 'Can we commit these changes for you?'
  });

  if (!confirm) {
    throw new Error('Aborting commit. Please review and commit the changes manually.');
  }

  const {
    message
  } = await (0, _prompts().default)({
    type: 'text',
    name: 'message',
    message: 'Commit message:',
    initial: commitMessage,
    validate: input => input !== ''
  }); // Add changed files only

  await (0, _spawnAsync().default)('git', ['add', '-u']);
  await (0, _spawnAsync().default)('git', ['commit', '-m', message]);
}
//# sourceMappingURL=git.js.map