"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.updateAndroidCredentialsAsync = updateAndroidCredentialsAsync;
exports.updateIosCredentialsAsync = updateIosCredentialsAsync;

function _fsExtra() {
  const data = _interopRequireDefault(require("fs-extra"));

  _fsExtra = function () {
    return data;
  };

  return data;
}

function _path() {
  const data = _interopRequireDefault(require("path"));

  _path = function () {
    return data;
  };

  return data;
}

function _prompts() {
  const data = _interopRequireDefault(require("prompts"));

  _prompts = function () {
    return data;
  };

  return data;
}

function _log() {
  const data = _interopRequireDefault(require("../../log"));

  _log = function () {
    return data;
  };

  return data;
}

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function updateAndroidCredentialsAsync(ctx) {
  var _rawCredentialsJsonOb, _rawCredentialsJsonOb2, _rawCredentialsJsonOb3;

  const credentialsJsonFilePath = _path().default.join(ctx.projectDir, 'credentials.json');

  let rawCredentialsJsonObject = {};

  if (await _fsExtra().default.pathExists(credentialsJsonFilePath)) {
    try {
      const rawFile = await _fsExtra().default.readFile(credentialsJsonFilePath, 'utf-8');
      rawCredentialsJsonObject = JSON.parse(rawFile);
    } catch (error) {
      _log().default.error(`There was an error while reading credentials.json [${error}]`);

      _log().default.error('Make sure that file is correct (or remove it) and rerun this command.');

      throw error;
    }
  }

  const experienceName = `@${ctx.manifest.owner || ctx.user.username}/${ctx.manifest.slug}`;
  const keystore = await ctx.android.fetchKeystore(experienceName);

  if (!keystore) {
    _log().default.error('There are no credentials configured for this project on Expo servers');

    return;
  }

  const isKeystoreComplete = keystore.keystore && keystore.keystorePassword && keystore.keyPassword && keystore.keyAlias;

  if (!isKeystoreComplete) {
    const {
      confirm
    } = await (0, _prompts().default)({
      type: 'confirm',
      name: 'confirm',
      message: 'Credentials on Expo servers might be invalid or incomplete. Are you sure you want to continue?'
    });

    if (!confirm) {
      _log().default.warn('Aborting...');

      return;
    }
  }

  const keystorePath = (_rawCredentialsJsonOb = (_rawCredentialsJsonOb2 = rawCredentialsJsonObject) === null || _rawCredentialsJsonOb2 === void 0 ? void 0 : (_rawCredentialsJsonOb3 = _rawCredentialsJsonOb2.android) === null || _rawCredentialsJsonOb3 === void 0 ? void 0 : _rawCredentialsJsonOb3.keystorePath) !== null && _rawCredentialsJsonOb !== void 0 ? _rawCredentialsJsonOb : './android/keystores/keystore.jks';
  (0, _log().default)(`Writing Keystore to ${keystorePath}`);
  await updateFileAsync(ctx.projectDir, keystorePath, keystore.keystore);
  rawCredentialsJsonObject.android = {
    keystore: {
      keystorePath,
      keystorePassword: keystore.keystorePassword,
      keyAlias: keystore.keyAlias,
      keyPassword: keystore.keyPassword
    }
  };
  await _fsExtra().default.writeJson(credentialsJsonFilePath, rawCredentialsJsonObject, {
    spaces: 2
  });
}

async function updateIosCredentialsAsync(ctx, bundleIdentifier) {
  var _ctx$manifest$owner, _rawCredentialsJsonOb4, _rawCredentialsJsonOb5, _rawCredentialsJsonOb6, _rawCredentialsJsonOb7, _rawCredentialsJsonOb8, _rawCredentialsJsonOb9, _appCredentials$crede, _appCredentials$crede2;

  const credentialsJsonFilePath = _path().default.join(ctx.projectDir, 'credentials.json');

  let rawCredentialsJsonObject = {};

  if (await _fsExtra().default.pathExists(credentialsJsonFilePath)) {
    try {
      const rawFile = await _fsExtra().default.readFile(credentialsJsonFilePath, 'utf-8');
      rawCredentialsJsonObject = JSON.parse(rawFile);
    } catch (error) {
      _log().default.error(`There was an error while reading credentials.json [${error}]`);

      _log().default.error('Make sure that file is correct (or remove it) and rerun this command.');

      throw error;
    }
  }

  const appLookupParams = {
    accountName: (_ctx$manifest$owner = ctx.manifest.owner) !== null && _ctx$manifest$owner !== void 0 ? _ctx$manifest$owner : ctx.user.username,
    projectName: ctx.manifest.slug,
    bundleIdentifier
  };
  const pprofilePath = (_rawCredentialsJsonOb4 = (_rawCredentialsJsonOb5 = rawCredentialsJsonObject) === null || _rawCredentialsJsonOb5 === void 0 ? void 0 : (_rawCredentialsJsonOb6 = _rawCredentialsJsonOb5.ios) === null || _rawCredentialsJsonOb6 === void 0 ? void 0 : _rawCredentialsJsonOb6.provisioningProfilePath) !== null && _rawCredentialsJsonOb4 !== void 0 ? _rawCredentialsJsonOb4 : './ios/certs/profile.mobileprovision';
  const distCertPath = (_rawCredentialsJsonOb7 = (_rawCredentialsJsonOb8 = rawCredentialsJsonObject) === null || _rawCredentialsJsonOb8 === void 0 ? void 0 : (_rawCredentialsJsonOb9 = _rawCredentialsJsonOb8.ios) === null || _rawCredentialsJsonOb9 === void 0 ? void 0 : _rawCredentialsJsonOb9.distributionCertificate.path) !== null && _rawCredentialsJsonOb7 !== void 0 ? _rawCredentialsJsonOb7 : './ios/certs/dist-cert.p12';
  const appCredentials = await ctx.ios.getAppCredentials(appLookupParams);
  const distCredentials = await ctx.ios.getDistCert(appLookupParams);

  if (!appCredentials && !distCredentials) {
    _log().default.error('There are no credentials configured for this project on Expo servers');

    return;
  }

  const areCredentialsComplete = (appCredentials === null || appCredentials === void 0 ? void 0 : (_appCredentials$crede = appCredentials.credentials) === null || _appCredentials$crede === void 0 ? void 0 : _appCredentials$crede.provisioningProfile) && (distCredentials === null || distCredentials === void 0 ? void 0 : distCredentials.certP12) && (distCredentials === null || distCredentials === void 0 ? void 0 : distCredentials.certPassword);

  if (!areCredentialsComplete) {
    const {
      confirm
    } = await (0, _prompts().default)({
      type: 'confirm',
      name: 'confirm',
      message: 'Credentials on Expo servers might be invalid or incomplete. Are you sure you want to continue?'
    });

    if (!confirm) {
      _log().default.warn('Aborting...');

      return;
    }
  }

  (0, _log().default)(`Writing Provisioning Profile to ${pprofilePath}`);
  await updateFileAsync(ctx.projectDir, pprofilePath, appCredentials === null || appCredentials === void 0 ? void 0 : (_appCredentials$crede2 = appCredentials.credentials) === null || _appCredentials$crede2 === void 0 ? void 0 : _appCredentials$crede2.provisioningProfile);
  (0, _log().default)(`Writing Distribution Certificate to ${distCertPath}`);
  await updateFileAsync(ctx.projectDir, distCertPath, distCredentials === null || distCredentials === void 0 ? void 0 : distCredentials.certP12);
  rawCredentialsJsonObject.ios = {
    provisioningProfilePath: pprofilePath,
    distributionCertificate: {
      path: distCertPath,
      password: distCredentials === null || distCredentials === void 0 ? void 0 : distCredentials.certPassword
    }
  };
  await _fsExtra().default.writeJson(credentialsJsonFilePath, rawCredentialsJsonObject, {
    spaces: 2
  });
}

async function updateFileAsync(projectDir, filePath, base64Data) {
  const absolutePath = _path().default.isAbsolute(filePath) ? filePath : _path().default.join(projectDir, filePath);

  if (await _fsExtra().default.pathExists(absolutePath)) {
    await _fsExtra().default.remove(absolutePath);
  }

  if (base64Data) {
    await _fsExtra().default.mkdirp(_path().default.dirname(filePath));
    await _fsExtra().default.writeFile(filePath, Buffer.from(base64Data, 'base64'));
  }
}
//# sourceMappingURL=update.js.map